Class: Aws::Pipes::Types::BatchRetryStrategy
- Inherits:
-
Struct
- Object
- Struct
- Aws::Pipes::Types::BatchRetryStrategy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pipes/types.rb
Overview
The retry strategy that’s associated with a job. For more information, see [ Automated job retries] in the *Batch User Guide*.
[1]: docs.aws.amazon.com/batch/latest/userguide/job_retries.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attempts ⇒ Integer
The number of times to move a job to the
RUNNABLEstatus.
Instance Attribute Details
#attempts ⇒ Integer
The number of times to move a job to the RUNNABLE status. If the value of attempts is greater than one, the job is retried on failure the same number of attempts as the value.
347 348 349 350 351 |
# File 'lib/aws-sdk-pipes/types.rb', line 347 class BatchRetryStrategy < Struct.new( :attempts) SENSITIVE = [] include Aws::Structure end |