Class: Aws::Pipes::Types::ListPipesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Pipes::Types::ListPipesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pipes/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:next_token]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available. -
#pipes ⇒ Array<Types::Pipe>
The pipes returned by the call.
Instance Attribute Details
#next_token ⇒ String
If nextToken is returned, there are more results available. The
value of nextToken is a unique pagination token for each page.
Make the call again using the returned token to retrieve the next
page. Keep all other arguments unchanged. Each pagination token
expires after 24 hours. Using an expired pagination token will
return an HTTP 400 InvalidToken error.
1276 1277 1278 1279 1280 1281 |
# File 'lib/aws-sdk-pipes/types.rb', line 1276 class ListPipesResponse < Struct.new( :pipes, :next_token) SENSITIVE = [:next_token] include Aws::Structure end |
#pipes ⇒ Array<Types::Pipe>
The pipes returned by the call.
1276 1277 1278 1279 1280 1281 |
# File 'lib/aws-sdk-pipes/types.rb', line 1276 class ListPipesResponse < Struct.new( :pipes, :next_token) SENSITIVE = [:next_token] include Aws::Structure end |