Class: Aws::Pipes::Types::PipeLogConfigurationParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::Pipes::Types::PipeLogConfigurationParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pipes/types.rb
Overview
Specifies the logging configuration settings for the pipe.
When you call UpdatePipe, EventBridge updates the fields in the PipeLogConfigurationParameters object atomically as one and overrides existing values. This is by design. If you don’t specify an optional field in any of the Amazon Web Services service parameters objects (CloudwatchLogsLogDestinationParameters, FirehoseLogDestinationParameters, or S3LogDestinationParameters), EventBridge sets that field to its system-default value during the update.
For example, suppose when you created the pipe you specified a Firehose stream log destination. You then update the pipe to add an Amazon S3 log destination. In addition to specifying the S3LogDestinationParameters for the new log destination, you must also specify the fields in the FirehoseLogDestinationParameters object in order to retain the Firehose stream log destination.
For more information on generating pipe log records, see [Log EventBridge Pipes](eventbridge/latest/userguide/eb-pipes-logs.html) in the *Amazon EventBridge User Guide*.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloudwatch_logs_log_destination ⇒ Types::CloudwatchLogsLogDestinationParameters
The Amazon CloudWatch Logs logging configuration settings for the pipe.
-
#firehose_log_destination ⇒ Types::FirehoseLogDestinationParameters
The Amazon Data Firehose logging configuration settings for the pipe.
-
#include_execution_data ⇒ Array<String>
Specify
ALLto include the execution data (specifically, thepayload,awsRequest, andawsResponsefields) in the log messages for this pipe. -
#level ⇒ String
The level of logging detail to include.
-
#s3_log_destination ⇒ Types::S3LogDestinationParameters
The Amazon S3 logging configuration settings for the pipe.
Instance Attribute Details
#cloudwatch_logs_log_destination ⇒ Types::CloudwatchLogsLogDestinationParameters
The Amazon CloudWatch Logs logging configuration settings for the pipe.
1691 1692 1693 1694 1695 1696 1697 1698 1699 |
# File 'lib/aws-sdk-pipes/types.rb', line 1691 class PipeLogConfigurationParameters < Struct.new( :s3_log_destination, :firehose_log_destination, :cloudwatch_logs_log_destination, :level, :include_execution_data) SENSITIVE = [] include Aws::Structure end |
#firehose_log_destination ⇒ Types::FirehoseLogDestinationParameters
The Amazon Data Firehose logging configuration settings for the pipe.
1691 1692 1693 1694 1695 1696 1697 1698 1699 |
# File 'lib/aws-sdk-pipes/types.rb', line 1691 class PipeLogConfigurationParameters < Struct.new( :s3_log_destination, :firehose_log_destination, :cloudwatch_logs_log_destination, :level, :include_execution_data) SENSITIVE = [] include Aws::Structure end |
#include_execution_data ⇒ Array<String>
Specify ALL to include the execution data (specifically, the payload, awsRequest, and awsResponse fields) in the log messages for this pipe.
This applies to all log destinations for the pipe.
For more information, see [Including execution data in logs] in the *Amazon EventBridge User Guide*.
By default, execution data is not included.
[1]: docs.aws.amazon.com/eventbridge/latest/userguide/eb-pipes-logs.html#eb-pipes-logs-execution-data
1691 1692 1693 1694 1695 1696 1697 1698 1699 |
# File 'lib/aws-sdk-pipes/types.rb', line 1691 class PipeLogConfigurationParameters < Struct.new( :s3_log_destination, :firehose_log_destination, :cloudwatch_logs_log_destination, :level, :include_execution_data) SENSITIVE = [] include Aws::Structure end |
#level ⇒ String
The level of logging detail to include. This applies to all log destinations for the pipe.
For more information, see [Specifying EventBridge Pipes log level] in the *Amazon EventBridge User Guide*.
[1]: docs.aws.amazon.com/eventbridge/latest/userguide/eb-pipes-logs.html#eb-pipes-logs-level
1691 1692 1693 1694 1695 1696 1697 1698 1699 |
# File 'lib/aws-sdk-pipes/types.rb', line 1691 class PipeLogConfigurationParameters < Struct.new( :s3_log_destination, :firehose_log_destination, :cloudwatch_logs_log_destination, :level, :include_execution_data) SENSITIVE = [] include Aws::Structure end |
#s3_log_destination ⇒ Types::S3LogDestinationParameters
The Amazon S3 logging configuration settings for the pipe.
1691 1692 1693 1694 1695 1696 1697 1698 1699 |
# File 'lib/aws-sdk-pipes/types.rb', line 1691 class PipeLogConfigurationParameters < Struct.new( :s3_log_destination, :firehose_log_destination, :cloudwatch_logs_log_destination, :level, :include_execution_data) SENSITIVE = [] include Aws::Structure end |