Class: Aws::Pipes::Types::PipeTargetEcsTaskParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::Pipes::Types::PipeTargetEcsTaskParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pipes/types.rb
Overview
The parameters for using an Amazon ECS task as a target.
Constant Summary collapse
- SENSITIVE =
[:reference_id]
Instance Attribute Summary collapse
-
#capacity_provider_strategy ⇒ Array<Types::CapacityProviderStrategyItem>
The capacity provider strategy to use for the task.
-
#enable_ecs_managed_tags ⇒ Boolean
Specifies whether to enable Amazon ECS managed tags for the task.
-
#enable_execute_command ⇒ Boolean
Whether or not to enable the execute command functionality for the containers in this task.
-
#group ⇒ String
Specifies an Amazon ECS task group for the task.
-
#launch_type ⇒ String
Specifies the launch type on which your task is running.
-
#network_configuration ⇒ Types::NetworkConfiguration
Use this structure if the Amazon ECS task uses the
awsvpcnetwork mode. -
#overrides ⇒ Types::EcsTaskOverride
The overrides that are associated with a task.
-
#placement_constraints ⇒ Array<Types::PlacementConstraint>
An array of placement constraint objects to use for the task.
-
#placement_strategy ⇒ Array<Types::PlacementStrategy>
The placement strategy objects to use for the task.
-
#platform_version ⇒ String
Specifies the platform version for the task.
-
#propagate_tags ⇒ String
Specifies whether to propagate the tags from the task definition to the task.
-
#reference_id ⇒ String
The reference ID to use for the task.
-
#tags ⇒ Array<Types::Tag>
The metadata that you apply to the task to help you categorize and organize them.
-
#task_count ⇒ Integer
The number of tasks to create based on
TaskDefinition. -
#task_definition_arn ⇒ String
The ARN of the task definition to use if the event target is an Amazon ECS task.
Instance Attribute Details
#capacity_provider_strategy ⇒ Array<Types::CapacityProviderStrategyItem>
The capacity provider strategy to use for the task.
If a capacityProviderStrategy is specified, the launchType parameter must be omitted. If no capacityProviderStrategy or launchType is specified, the defaultCapacityProviderStrategy for the cluster is used.
2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 |
# File 'lib/aws-sdk-pipes/types.rb', line 2290 class PipeTargetEcsTaskParameters < Struct.new( :task_definition_arn, :task_count, :launch_type, :network_configuration, :platform_version, :group, :capacity_provider_strategy, :enable_ecs_managed_tags, :enable_execute_command, :placement_constraints, :placement_strategy, :propagate_tags, :reference_id, :overrides, :tags) SENSITIVE = [:reference_id] include Aws::Structure end |
#enable_ecs_managed_tags ⇒ Boolean
Specifies whether to enable Amazon ECS managed tags for the task. For more information, see [Tagging Your Amazon ECS Resources] in the Amazon Elastic Container Service Developer Guide.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-using-tags.html
2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 |
# File 'lib/aws-sdk-pipes/types.rb', line 2290 class PipeTargetEcsTaskParameters < Struct.new( :task_definition_arn, :task_count, :launch_type, :network_configuration, :platform_version, :group, :capacity_provider_strategy, :enable_ecs_managed_tags, :enable_execute_command, :placement_constraints, :placement_strategy, :propagate_tags, :reference_id, :overrides, :tags) SENSITIVE = [:reference_id] include Aws::Structure end |
#enable_execute_command ⇒ Boolean
Whether or not to enable the execute command functionality for the containers in this task. If true, this enables execute command functionality on all containers in the task.
2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 |
# File 'lib/aws-sdk-pipes/types.rb', line 2290 class PipeTargetEcsTaskParameters < Struct.new( :task_definition_arn, :task_count, :launch_type, :network_configuration, :platform_version, :group, :capacity_provider_strategy, :enable_ecs_managed_tags, :enable_execute_command, :placement_constraints, :placement_strategy, :propagate_tags, :reference_id, :overrides, :tags) SENSITIVE = [:reference_id] include Aws::Structure end |
#group ⇒ String
Specifies an Amazon ECS task group for the task. The maximum length is 255 characters.
2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 |
# File 'lib/aws-sdk-pipes/types.rb', line 2290 class PipeTargetEcsTaskParameters < Struct.new( :task_definition_arn, :task_count, :launch_type, :network_configuration, :platform_version, :group, :capacity_provider_strategy, :enable_ecs_managed_tags, :enable_execute_command, :placement_constraints, :placement_strategy, :propagate_tags, :reference_id, :overrides, :tags) SENSITIVE = [:reference_id] include Aws::Structure end |
#launch_type ⇒ String
Specifies the launch type on which your task is running. The launch type that you specify here must match one of the launch type (compatibilities) of the target task. The FARGATE value is supported only in the Regions where Fargate with Amazon ECS is supported. For more information, see [Fargate on Amazon ECS] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/AWS-Fargate.html
2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 |
# File 'lib/aws-sdk-pipes/types.rb', line 2290 class PipeTargetEcsTaskParameters < Struct.new( :task_definition_arn, :task_count, :launch_type, :network_configuration, :platform_version, :group, :capacity_provider_strategy, :enable_ecs_managed_tags, :enable_execute_command, :placement_constraints, :placement_strategy, :propagate_tags, :reference_id, :overrides, :tags) SENSITIVE = [:reference_id] include Aws::Structure end |
#network_configuration ⇒ Types::NetworkConfiguration
Use this structure if the Amazon ECS task uses the awsvpc network mode. This structure specifies the VPC subnets and security groups associated with the task, and whether a public IP address is to be used. This structure is required if LaunchType is FARGATE because the awsvpc mode is required for Fargate tasks.
If you specify NetworkConfiguration when the target ECS task does not use the awsvpc network mode, the task fails.
2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 |
# File 'lib/aws-sdk-pipes/types.rb', line 2290 class PipeTargetEcsTaskParameters < Struct.new( :task_definition_arn, :task_count, :launch_type, :network_configuration, :platform_version, :group, :capacity_provider_strategy, :enable_ecs_managed_tags, :enable_execute_command, :placement_constraints, :placement_strategy, :propagate_tags, :reference_id, :overrides, :tags) SENSITIVE = [:reference_id] include Aws::Structure end |
#overrides ⇒ Types::EcsTaskOverride
The overrides that are associated with a task.
2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 |
# File 'lib/aws-sdk-pipes/types.rb', line 2290 class PipeTargetEcsTaskParameters < Struct.new( :task_definition_arn, :task_count, :launch_type, :network_configuration, :platform_version, :group, :capacity_provider_strategy, :enable_ecs_managed_tags, :enable_execute_command, :placement_constraints, :placement_strategy, :propagate_tags, :reference_id, :overrides, :tags) SENSITIVE = [:reference_id] include Aws::Structure end |
#placement_constraints ⇒ Array<Types::PlacementConstraint>
An array of placement constraint objects to use for the task. You can specify up to 10 constraints per task (including constraints in the task definition and those specified at runtime).
2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 |
# File 'lib/aws-sdk-pipes/types.rb', line 2290 class PipeTargetEcsTaskParameters < Struct.new( :task_definition_arn, :task_count, :launch_type, :network_configuration, :platform_version, :group, :capacity_provider_strategy, :enable_ecs_managed_tags, :enable_execute_command, :placement_constraints, :placement_strategy, :propagate_tags, :reference_id, :overrides, :tags) SENSITIVE = [:reference_id] include Aws::Structure end |
#placement_strategy ⇒ Array<Types::PlacementStrategy>
The placement strategy objects to use for the task. You can specify a maximum of five strategy rules per task.
2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 |
# File 'lib/aws-sdk-pipes/types.rb', line 2290 class PipeTargetEcsTaskParameters < Struct.new( :task_definition_arn, :task_count, :launch_type, :network_configuration, :platform_version, :group, :capacity_provider_strategy, :enable_ecs_managed_tags, :enable_execute_command, :placement_constraints, :placement_strategy, :propagate_tags, :reference_id, :overrides, :tags) SENSITIVE = [:reference_id] include Aws::Structure end |
#platform_version ⇒ String
Specifies the platform version for the task. Specify only the numeric portion of the platform version, such as 1.1.0.
This structure is used only if LaunchType is FARGATE. For more information about valid platform versions, see [Fargate Platform Versions] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html
2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 |
# File 'lib/aws-sdk-pipes/types.rb', line 2290 class PipeTargetEcsTaskParameters < Struct.new( :task_definition_arn, :task_count, :launch_type, :network_configuration, :platform_version, :group, :capacity_provider_strategy, :enable_ecs_managed_tags, :enable_execute_command, :placement_constraints, :placement_strategy, :propagate_tags, :reference_id, :overrides, :tags) SENSITIVE = [:reference_id] include Aws::Structure end |
#propagate_tags ⇒ String
Specifies whether to propagate the tags from the task definition to the task. If no value is specified, the tags are not propagated. Tags can only be propagated to the task during task creation. To add tags to a task after task creation, use the TagResource API action.
2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 |
# File 'lib/aws-sdk-pipes/types.rb', line 2290 class PipeTargetEcsTaskParameters < Struct.new( :task_definition_arn, :task_count, :launch_type, :network_configuration, :platform_version, :group, :capacity_provider_strategy, :enable_ecs_managed_tags, :enable_execute_command, :placement_constraints, :placement_strategy, :propagate_tags, :reference_id, :overrides, :tags) SENSITIVE = [:reference_id] include Aws::Structure end |
#reference_id ⇒ String
The reference ID to use for the task.
2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 |
# File 'lib/aws-sdk-pipes/types.rb', line 2290 class PipeTargetEcsTaskParameters < Struct.new( :task_definition_arn, :task_count, :launch_type, :network_configuration, :platform_version, :group, :capacity_provider_strategy, :enable_ecs_managed_tags, :enable_execute_command, :placement_constraints, :placement_strategy, :propagate_tags, :reference_id, :overrides, :tags) SENSITIVE = [:reference_id] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The metadata that you apply to the task to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. To learn more, see [RunTask] in the Amazon ECS API Reference.
[1]: docs.aws.amazon.com/AmazonECS/latest/APIReference/API_RunTask.html#ECS-RunTask-request-tags
2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 |
# File 'lib/aws-sdk-pipes/types.rb', line 2290 class PipeTargetEcsTaskParameters < Struct.new( :task_definition_arn, :task_count, :launch_type, :network_configuration, :platform_version, :group, :capacity_provider_strategy, :enable_ecs_managed_tags, :enable_execute_command, :placement_constraints, :placement_strategy, :propagate_tags, :reference_id, :overrides, :tags) SENSITIVE = [:reference_id] include Aws::Structure end |
#task_count ⇒ Integer
The number of tasks to create based on TaskDefinition. The default is 1.
2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 |
# File 'lib/aws-sdk-pipes/types.rb', line 2290 class PipeTargetEcsTaskParameters < Struct.new( :task_definition_arn, :task_count, :launch_type, :network_configuration, :platform_version, :group, :capacity_provider_strategy, :enable_ecs_managed_tags, :enable_execute_command, :placement_constraints, :placement_strategy, :propagate_tags, :reference_id, :overrides, :tags) SENSITIVE = [:reference_id] include Aws::Structure end |
#task_definition_arn ⇒ String
The ARN of the task definition to use if the event target is an Amazon ECS task.
2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 |
# File 'lib/aws-sdk-pipes/types.rb', line 2290 class PipeTargetEcsTaskParameters < Struct.new( :task_definition_arn, :task_count, :launch_type, :network_configuration, :platform_version, :group, :capacity_provider_strategy, :enable_ecs_managed_tags, :enable_execute_command, :placement_constraints, :placement_strategy, :propagate_tags, :reference_id, :overrides, :tags) SENSITIVE = [:reference_id] include Aws::Structure end |