Class: Aws::Pipes::Types::PipeTargetEventBridgeEventBusParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pipes/types.rb

Overview

The parameters for using an EventBridge event bus as a target.

Constant Summary collapse

SENSITIVE =
[:endpoint_id, :detail_type, :source]

Instance Attribute Summary collapse

Instance Attribute Details

#detail_typeString

A free-form string, with a maximum of 128 characters, used to decide what fields to expect in the event detail.



2345
2346
2347
2348
2349
2350
2351
2352
2353
# File 'lib/aws-sdk-pipes/types.rb', line 2345

class PipeTargetEventBridgeEventBusParameters < Struct.new(
  :endpoint_id,
  :detail_type,
  :source,
  :resources,
  :time)
  SENSITIVE = [:endpoint_id, :detail_type, :source]
  include Aws::Structure
end

#endpoint_idString

The URL subdomain of the endpoint. For example, if the URL for Endpoint is abcde.veo.endpoints.event.amazonaws.com, then the EndpointId is abcde.veo.



2345
2346
2347
2348
2349
2350
2351
2352
2353
# File 'lib/aws-sdk-pipes/types.rb', line 2345

class PipeTargetEventBridgeEventBusParameters < Struct.new(
  :endpoint_id,
  :detail_type,
  :source,
  :resources,
  :time)
  SENSITIVE = [:endpoint_id, :detail_type, :source]
  include Aws::Structure
end

#resourcesArray<String>

Amazon Web Services resources, identified by Amazon Resource Name (ARN), which the event primarily concerns. Any number, including zero, may be present.



2345
2346
2347
2348
2349
2350
2351
2352
2353
# File 'lib/aws-sdk-pipes/types.rb', line 2345

class PipeTargetEventBridgeEventBusParameters < Struct.new(
  :endpoint_id,
  :detail_type,
  :source,
  :resources,
  :time)
  SENSITIVE = [:endpoint_id, :detail_type, :source]
  include Aws::Structure
end

#sourceString

The source of the event.



2345
2346
2347
2348
2349
2350
2351
2352
2353
# File 'lib/aws-sdk-pipes/types.rb', line 2345

class PipeTargetEventBridgeEventBusParameters < Struct.new(
  :endpoint_id,
  :detail_type,
  :source,
  :resources,
  :time)
  SENSITIVE = [:endpoint_id, :detail_type, :source]
  include Aws::Structure
end

#timeString

The time stamp of the event, per [RFC3339]. If no time stamp is provided, the time stamp of the [PutEvents] call is used.

[1]: www.rfc-editor.org/rfc/rfc3339.txt [2]: docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutEvents.html



2345
2346
2347
2348
2349
2350
2351
2352
2353
# File 'lib/aws-sdk-pipes/types.rb', line 2345

class PipeTargetEventBridgeEventBusParameters < Struct.new(
  :endpoint_id,
  :detail_type,
  :source,
  :resources,
  :time)
  SENSITIVE = [:endpoint_id, :detail_type, :source]
  include Aws::Structure
end