Class: Aws::Pipes::Types::PipeTargetLambdaFunctionParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::Pipes::Types::PipeTargetLambdaFunctionParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pipes/types.rb
Overview
The parameters for using a Lambda function as a target.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#invocation_type ⇒ String
Specify whether to invoke the function synchronously or asynchronously.
Instance Attribute Details
#invocation_type ⇒ String
Specify whether to invoke the function synchronously or asynchronously.
-
REQUEST_RESPONSE(default) - Invoke synchronously. This corresponds to theRequestResponseoption in theInvocationTypeparameter for the Lambda [Invoke] API. -
FIRE_AND_FORGET- Invoke asynchronously. This corresponds to theEventoption in theInvocationTypeparameter for the Lambda- Invoke][1
-
API.
For more information, see [Invocation types] in the *Amazon EventBridge User Guide*.
[1]: docs.aws.amazon.com/lambda/latest/dg/API_Invoke.html#API_Invoke_RequestSyntax [2]: docs.aws.amazon.com/eventbridge/latest/userguide/eb-pipes.html#pipes-invocation
2430 2431 2432 2433 2434 |
# File 'lib/aws-sdk-pipes/types.rb', line 2430 class PipeTargetLambdaFunctionParameters < Struct.new( :invocation_type) SENSITIVE = [] include Aws::Structure end |