Class: Aws::Pipes::Types::PipeTargetStateMachineParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::Pipes::Types::PipeTargetStateMachineParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pipes/types.rb
Overview
The parameters for using a Step Functions state machine as a target.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#invocation_type ⇒ String
Specify whether to invoke the Step Functions state machine synchronously or asynchronously.
Instance Attribute Details
#invocation_type ⇒ String
Specify whether to invoke the Step Functions state machine synchronously or asynchronously.
-
REQUEST_RESPONSE(default) - Invoke synchronously. For more information, see [StartSyncExecution] in the *Step Functions API Reference*.<note markdown=“1”>
REQUEST_RESPONSEis not supported forSTANDARDstate machine workflows.</note> -
FIRE_AND_FORGET- Invoke asynchronously. For more information, see [StartExecution] in the *Step Functions API Reference*.
For more information, see [Invocation types] in the *Amazon EventBridge User Guide*.
[1]: docs.aws.amazon.com/step-functions/latest/apireference/API_StartSyncExecution.html [2]: docs.aws.amazon.com/step-functions/latest/apireference/API_StartExecution.html [3]: docs.aws.amazon.com/eventbridge/latest/userguide/eb-pipes.html#pipes-invocation
2642 2643 2644 2645 2646 |
# File 'lib/aws-sdk-pipes/types.rb', line 2642 class PipeTargetStateMachineParameters < Struct.new( :invocation_type) SENSITIVE = [] include Aws::Structure end |