Class: Aws::Pipes::Types::UpdatePipeSourceKinesisStreamParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pipes/types.rb

Overview

The parameters for using a Kinesis stream as a source.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#batch_sizeInteger

The maximum number of records to include in each batch.



3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
# File 'lib/aws-sdk-pipes/types.rb', line 3493

class UpdatePipeSourceKinesisStreamParameters < Struct.new(
  :batch_size,
  :dead_letter_config,
  :on_partial_batch_item_failure,
  :maximum_batching_window_in_seconds,
  :maximum_record_age_in_seconds,
  :maximum_retry_attempts,
  :parallelization_factor)
  SENSITIVE = []
  include Aws::Structure
end

#dead_letter_configTypes::DeadLetterConfig

Define the target queue to send dead-letter queue events to.



3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
# File 'lib/aws-sdk-pipes/types.rb', line 3493

class UpdatePipeSourceKinesisStreamParameters < Struct.new(
  :batch_size,
  :dead_letter_config,
  :on_partial_batch_item_failure,
  :maximum_batching_window_in_seconds,
  :maximum_record_age_in_seconds,
  :maximum_retry_attempts,
  :parallelization_factor)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_batching_window_in_secondsInteger

The maximum length of a time to wait for events.



3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
# File 'lib/aws-sdk-pipes/types.rb', line 3493

class UpdatePipeSourceKinesisStreamParameters < Struct.new(
  :batch_size,
  :dead_letter_config,
  :on_partial_batch_item_failure,
  :maximum_batching_window_in_seconds,
  :maximum_record_age_in_seconds,
  :maximum_retry_attempts,
  :parallelization_factor)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_record_age_in_secondsInteger

Discard records older than the specified age. The default value is -1, which sets the maximum age to infinite. When the value is set to infinite, EventBridge never discards old records.



3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
# File 'lib/aws-sdk-pipes/types.rb', line 3493

class UpdatePipeSourceKinesisStreamParameters < Struct.new(
  :batch_size,
  :dead_letter_config,
  :on_partial_batch_item_failure,
  :maximum_batching_window_in_seconds,
  :maximum_record_age_in_seconds,
  :maximum_retry_attempts,
  :parallelization_factor)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_retry_attemptsInteger

Discard records after the specified number of retries. The default value is -1, which sets the maximum number of retries to infinite. When MaximumRetryAttempts is infinite, EventBridge retries failed records until the record expires in the event source.



3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
# File 'lib/aws-sdk-pipes/types.rb', line 3493

class UpdatePipeSourceKinesisStreamParameters < Struct.new(
  :batch_size,
  :dead_letter_config,
  :on_partial_batch_item_failure,
  :maximum_batching_window_in_seconds,
  :maximum_record_age_in_seconds,
  :maximum_retry_attempts,
  :parallelization_factor)
  SENSITIVE = []
  include Aws::Structure
end

#on_partial_batch_item_failureString

Define how to handle item process failures. AUTOMATIC_BISECT halves each batch and retry each half until all the records are processed or there is one failed message left in the batch.



3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
# File 'lib/aws-sdk-pipes/types.rb', line 3493

class UpdatePipeSourceKinesisStreamParameters < Struct.new(
  :batch_size,
  :dead_letter_config,
  :on_partial_batch_item_failure,
  :maximum_batching_window_in_seconds,
  :maximum_record_age_in_seconds,
  :maximum_retry_attempts,
  :parallelization_factor)
  SENSITIVE = []
  include Aws::Structure
end

#parallelization_factorInteger

The number of batches to process concurrently from each shard. The default value is 1.



3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
# File 'lib/aws-sdk-pipes/types.rb', line 3493

class UpdatePipeSourceKinesisStreamParameters < Struct.new(
  :batch_size,
  :dead_letter_config,
  :on_partial_batch_item_failure,
  :maximum_batching_window_in_seconds,
  :maximum_record_age_in_seconds,
  :maximum_retry_attempts,
  :parallelization_factor)
  SENSITIVE = []
  include Aws::Structure
end